from ._color import Color, reset


def ansi_print(text="", *args, color: Color = "", sep: str = ' ', end: str = f"{Color(reset.all)}\n", file=None):
    print(f"{color}{text}", *args, sep=sep, end=end, file=file)


def ansi_string(text="", *args, color: Color = "", sep: str = ' ', end: str = f"{Color(reset.all)}\n"):
    return f"{color}{sep.join([text] + [str(arg) for arg in args])}{end}"

