
class style:
    bold = 1
    faint = 2
    italic = 3
    underline = 4
    blink_slow = 5
    blink_fast = 6
    invert_color = 7
    hide = 8
    strike = 9
    reset_font = 10
    font_1 = 11
    font_2 = 12
    font_3 = 13
    font_4 = 14
    font_5 = 15
    font_6 = 16
    font_7 = 17
    font_8 = 18
    font_9 = 19
    gothic = 20
    underline_double = 21
