
class move:
    home = "H"

    @staticmethod
    def position(line, column):
        return f"{line};{column}H"

    @staticmethod
    def up(n):
        return f"{n}A"

    @staticmethod
    def down(n):
        return f"{n}B"

    @staticmethod
    def right(n):
        return f"{n}C"

    @staticmethod
    def left(n):
        return f"{n}D"
