from importlib.metadata import version
__version__ = version('ansi_terminal')

from ._ansi_print import ansi_print, ansi_string
from ._color import Color, bg, fg, style, reset
from ._cursor import Cursor, move
from ._display import Display, erase
