

class erase:
    in_display = "J"
    till_end_display = "0J"
    from_start_display = "1J"
    entire_display = "2J"
    saved = "3J"

    in_line = "K"
    till_end_line = "0K"
    from_start_line = "1K"
    entire_line = "2K"
