
class bg:
    reset = 49

    black = 40
    red = 41
    green = 42
    yellow = 43
    blue = 44
    magenta = 45
    cyan = 46
    white = 47

    bright_black = 100
    bright_red = 101
    bright_green = 102
    bright_yellow = 103
    bright_blue = 104
    bright_magenta = 105
    bright_cyan = 106
    bright_white = 107

    @staticmethod
    def id(n: int):
        return f"48;5;{n}"

    @staticmethod
    def rgb(r: int, g: int, b: int):
        return f"48;2;{r};{g};{b}"
